@@ -7,6 +7,7 @@ import (
 	"github.com/abiosoft/colima/cmd/root"
 	"github.com/abiosoft/colima/config"
 	"github.com/abiosoft/colima/daemon/process"
+	"github.com/abiosoft/colima/daemon/process/gvproxy"
 	"github.com/abiosoft/colima/daemon/process/vmnet"
 	"github.com/spf13/cobra"
 )
@@ -31,6 +32,9 @@ var startCmd = &cobra.Command{
 		if daemonArgs.vmnet {
 			processes = append(processes, vmnet.New())
 		}
+		if daemonArgs.gvproxy.enabled {
+			processes = append(processes, gvproxy.New(daemonArgs.gvproxy.dnsHosts))
+		}
 
 		return start(ctx, processes)
 	},
@@ -66,8 +70,11 @@ var statusCmd = &cobra.Command{
 }
 
 var daemonArgs struct {
-	vmnet    bool
-	gvproxy  bool
+	vmnet   bool
+	gvproxy struct {
+		enabled  bool
+		dnsHosts map[string]string
+	}
 	fsnotify bool
 
 	verbose bool
@@ -81,6 +88,7 @@ func init() {
 	daemonCmd.AddCommand(statusCmd)
 
 	startCmd.Flags().BoolVar(&daemonArgs.vmnet, "vmnet", false, "start vmnet")
-	startCmd.Flags().BoolVar(&daemonArgs.gvproxy, "gvproxy", false, "start gvproxy")
+	startCmd.Flags().BoolVar(&daemonArgs.gvproxy.enabled, "gvproxy", false, "start gvproxy")
+	startCmd.Flags().StringToStringVar(&daemonArgs.gvproxy.dnsHosts, "gvproxy-hosts", nil, "start gvproxy")
 	startCmd.Flags().BoolVar(&daemonArgs.fsnotify, "fsnotify", false, "start fsnotify")
 }
