@@ -64,6 +64,11 @@ Run 'colima template' to set the default configurations or 'colima start --edit'
 			return fmt.Errorf("error opening config file: %w", err)
 		}
 
+		// validate config
+		if err := configmanager.ValidateConfig(conf); err != nil {
+			return fmt.Errorf("error in config file: %w", err)
+		}
+
 		if app.Active() {
 			if !cli.Prompt("colima is currently running, restart to apply changes") {
 				return nil
@@ -72,7 +77,7 @@ Run 'colima template' to set the default configurations or 'colima start --edit'
 				return fmt.Errorf("error stopping :%w", err)
 			}
 			// pause before startup to prevent race condition
-			time.Sleep(time.Second * 5)
+			time.Sleep(time.Second * 3)
 		}
 
 		return app.Start(conf)
@@ -81,6 +86,11 @@ Run 'colima template' to set the default configurations or 'colima start --edit'
 		// combine args and current config file(if any)
 		prepareConfig(cmd)
 
+		// validate config
+		if err := configmanager.ValidateConfig(startCmdArgs.Config); err != nil {
+			return fmt.Errorf("error in config: %w", err)
+		}
+
 		// persist in preparing of application start
 		if err := configmanager.Save(startCmdArgs.Config); err != nil {
 			return fmt.Errorf("error preparing config file: %w", err)
@@ -142,6 +152,9 @@ func init() {
 	}
 	if util.MacOS13OrNewer() {
 		startCmd.Flags().StringVarP(&startCmdArgs.VMType, "vm-type", "t", defaultVMType, "virtual machine type ("+types+")")
+		if util.MacOS13OrNewerOnM1() {
+			startCmd.Flags().BoolVar(&startCmdArgs.VZRosetta, "vz-rosetta", false, "enable Rosetta for amd64 emulation")
+		}
 	}
 
 	// config
@@ -217,6 +230,14 @@ func mountsFromFlag(mounts []string) []config.Mount {
 }
 
 func setDefaults(cmd *cobra.Command) {
+	if startCmdArgs.VMType == "" {
+		startCmdArgs.VMType = defaultVMType
+	}
+
+	if startCmdArgs.Network.Driver == "" {
+		startCmdArgs.Network.Driver = defaultNetworkDriver
+	}
+
 	if util.MacOS13OrNewer() {
 		// changing to vz implies changing mount type to virtiofs
 		if cmd.Flag("vm-type").Changed && startCmdArgs.VMType == "vz" && !cmd.Flag("mount-type").Changed {
@@ -359,6 +380,11 @@ func prepareConfig(cmd *cobra.Command) {
 				startCmdArgs.VMType = current.VMType
 			}
 		}
+		if util.MacOS13OrNewerOnM1() {
+			if !cmd.Flag("vz-rosetta").Changed {
+				startCmdArgs.VZRosetta = current.VZRosetta
+			}
+		}
 	}
 }
 
