@@ -1,6 +1,7 @@
 package yamlutil
 
 import (
+	"net"
 	"reflect"
 	"testing"
 
@@ -10,7 +11,9 @@ import (
 
 func Test_encode_Docker(t *testing.T) {
 	conf := config.Config{
-		Docker: map[string]any{"insecure-registries": []any{"127.0.0.1"}},
+		Docker:     map[string]any{"insecure-registries": []any{"127.0.0.1"}},
+		Network:    config.Network{DNSResolvers: []net.IP{net.ParseIP("1.1.1.1")}},
+		Kubernetes: config.Kubernetes{Disable: []string{"treafik"}},
 	}
 
 	tests := []struct {
